aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--Makefile2
-rw-r--r--README.txt4
-rw-r--r--push.sh5
3 files changed, 5 insertions, 6 deletions
diff --git a/Makefile b/Makefile
index adbbb7d..fb07e76 100644
--- a/Makefile
+++ b/Makefile
@@ -155,7 +155,7 @@ help:
echo " Fenders 3-sector Loader floppy image [*]"
@echo
@echo "[*] floppy image targets require 'axe' utility, from:"
- @echo " http://urchlay.naptime.net/~urchlay/src/axe-0.2.0.tar.gz"
+ @echo " https://slackware.uk/~urchlay/src/axe-0.2.0.tar.gz"
@echo
@echo "Useful variables to add to the make command:"
@echo " CC - path to cl65 binary (default: cl65, searches PATH)"
diff --git a/README.txt b/README.txt
index ce099d9..6d9738b 100644
--- a/README.txt
+++ b/README.txt
@@ -7,11 +7,11 @@ Currently the game is playable and complete, but has a few known bugs
(see "Bugs" section below) and probably a few unknown ones too.
The latest version of the source can be found here:
-http://urchlay.naptime.net/repos/taipan/
+https://slackware.uk/~urchlay/repos/taipan
A binary of the game can be found here:
-http://urchlay.naptime.net/~urchlay/src/taipan.xex
+https://slackware.uk/~urchlay/src/taipan.xex
...though it might be outdated.
diff --git a/push.sh b/push.sh
index 69c9cae..26db1b7 100644
--- a/push.sh
+++ b/push.sh
@@ -2,11 +2,10 @@
# push to git, create a new build from scratch, post it on webserver,
# and print the short git hash (for copy/pasting into irc).
# "naptime" is a shell script that you don't have :)
git push && make distclean all || exit 1
-#URL="$( naptime taipan.xex | sed 's,urchlay.naptime.net,204.9.204.226,' )"
-URL="$( naptime taipan.xex )"
+URL="$( sluk taipan.xex )"
REV="$( git rev-parse --short HEAD )"
echo "build ID $REV at $URL"
@@ -2,11 +2,10 @@
# push to git, create a new build from scratch, post it on webserver,
# and print the short git hash (for copy/pasting into irc).
-# "naptime" is a shell script that you don't have :)
+# "sluk" is a shell script that you don't have :)
git push && make distclean all || exit 1